[![PyPI version](https://badge.fury.io/py/jablotronpy.svg)](https://badge.fury.io/py/jablotronpy)
# JablotronPy

Due to popular request, work has started on a Jablotron client for Python that will be used to
write a Jablotron plugin for Home Assistant. It will also be used in a simple gui that 
will help people setup their Homebridge config. 
